/*******************************************************************************
* File Name: clock_Timer.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_clock_Timer_H)
#define CY_CLOCK_clock_Timer_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void clock_Timer_Start(void) ;
void clock_Timer_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void clock_Timer_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void clock_Timer_StandbyPower(uint8 state) ;
void clock_Timer_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 clock_Timer_GetDividerRegister(void) ;
void clock_Timer_SetModeRegister(uint8 modeBitMask) ;
void clock_Timer_ClearModeRegister(uint8 modeBitMask) ;
uint8 clock_Timer_GetModeRegister(void) ;
void clock_Timer_SetSourceRegister(uint8 clkSource) ;
uint8 clock_Timer_GetSourceRegister(void) ;
#if defined(clock_Timer__CFG3)
void clock_Timer_SetPhaseRegister(uint8 clkPhase) ;
uint8 clock_Timer_GetPhaseRegister(void) ;
#endif /* defined(clock_Timer__CFG3) */

#define clock_Timer_Enable()                       clock_Timer_Start()
#define clock_Timer_Disable()                      clock_Timer_Stop()
#define clock_Timer_SetDivider(clkDivider)         clock_Timer_SetDividerRegister(clkDivider, 1u)
#define clock_Timer_SetDividerValue(clkDivider)    clock_Timer_SetDividerRegister((clkDivider) - 1u, 1u)
#define clock_Timer_SetMode(clkMode)               clock_Timer_SetModeRegister(clkMode)
#define clock_Timer_SetSource(clkSource)           clock_Timer_SetSourceRegister(clkSource)
#if defined(clock_Timer__CFG3)
#define clock_Timer_SetPhase(clkPhase)             clock_Timer_SetPhaseRegister(clkPhase)
#define clock_Timer_SetPhaseValue(clkPhase)        clock_Timer_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(clock_Timer__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define clock_Timer_CLKEN              (* (reg8 *) clock_Timer__PM_ACT_CFG)
#define clock_Timer_CLKEN_PTR          ((reg8 *) clock_Timer__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define clock_Timer_CLKSTBY            (* (reg8 *) clock_Timer__PM_STBY_CFG)
#define clock_Timer_CLKSTBY_PTR        ((reg8 *) clock_Timer__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define clock_Timer_DIV_LSB            (* (reg8 *) clock_Timer__CFG0)
#define clock_Timer_DIV_LSB_PTR        ((reg8 *) clock_Timer__CFG0)
#define clock_Timer_DIV_PTR            ((reg16 *) clock_Timer__CFG0)

/* Clock MSB divider configuration register. */
#define clock_Timer_DIV_MSB            (* (reg8 *) clock_Timer__CFG1)
#define clock_Timer_DIV_MSB_PTR        ((reg8 *) clock_Timer__CFG1)

/* Mode and source configuration register */
#define clock_Timer_MOD_SRC            (* (reg8 *) clock_Timer__CFG2)
#define clock_Timer_MOD_SRC_PTR        ((reg8 *) clock_Timer__CFG2)

#if defined(clock_Timer__CFG3)
/* Analog clock phase configuration register */
#define clock_Timer_PHASE              (* (reg8 *) clock_Timer__CFG3)
#define clock_Timer_PHASE_PTR          ((reg8 *) clock_Timer__CFG3)
#endif /* defined(clock_Timer__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define clock_Timer_CLKEN_MASK         clock_Timer__PM_ACT_MSK
#define clock_Timer_CLKSTBY_MASK       clock_Timer__PM_STBY_MSK

/* CFG2 field masks */
#define clock_Timer_SRC_SEL_MSK        clock_Timer__CFG2_SRC_SEL_MASK
#define clock_Timer_MODE_MASK          (~(clock_Timer_SRC_SEL_MSK))

#if defined(clock_Timer__CFG3)
/* CFG3 phase mask */
#define clock_Timer_PHASE_MASK         clock_Timer__CFG3_PHASE_DLY_MASK
#endif /* defined(clock_Timer__CFG3) */

#endif /* CY_CLOCK_clock_Timer_H */


/* [] END OF FILE */
