/* ============================================
 *
 * Test of DMA transfer from SRAM to ControlReg
 *
 * Every 500ms the CPU will request a DMA transfer,
 * when the transfer is completed UART will print
 * the ControlReg content to ensure a correct transfer.
 *
 * ============================================
*/
#include <project.h>
#include "cyapicallbacks.h"


#define NO_SAMPLES  16

//static const uint8_t Buffer[NO_SAMPLES] = {0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15}; // flash, read-only 
//static void * const pBuffer = Buffer;  //not working

//uint8_t Buffer[NO_SAMPLES] = {0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15}; // SRAM, can be modified
uint8_t Buffer[NO_SAMPLES]; // SRAM, can be modified
//static void * const pBuffer = Buffer;  //ok
//uint8 * pBuffer = &(Buffer[0]); //ok
uint8 * pBuffer = Buffer; //ok

//uint8_t DMA_Chan; // Variable declarations for DMA 


void DMAConfig(void);

void Initialize()
{
    uint8 i; 
    for (i=0; i<NO_SAMPLES; i++) Buffer[i] = i;
        
    
    CyGlobalIntEnable;
        
    DMAConfig();
    isr_DMA_Start();
    
    //UART_Start();
    //UART_PutString("Test SRAM -> DMA -> ControlReg\r\n");
    
    Timer_Start();
}

int main(void)
{
    
    Initialize();

    for(;;){} //forever
}




//=============================================================================

void isr_DMA_Interrupt_InterruptCallback(void){
    
    //CyDmaChDisable(DMA_Chan); /* Disable DMA Channel */
    LED_Write(~LED_Read());
    //UART_PutHexByte(ControlReg_Read());
    //UART_PutCRLF();
    //CyDmaChEnable(DMA_Chan, 1);    /* Enable DMA channel */
    // CyDmaChSetRequest(DMA_Chan, CPU_REQ);
    
    return;
}

//=============================================================================

void DMAConfig(void){
    
    /* Variable declarations for DMA */
    uint8_t DMA_Chan;
    uint8_t DMA_TD[1];
    
    /* Defines for DMA */
    #define DMA_BYTES_PER_BURST 1
    #define DMA_REQUEST_PER_BURST 1
    //#define DMA_SRC_BASE (&Buffer[0]) // original
    #define DMA_SRC_BASE (pBuffer) // seems ok, needs testing
    #define DMA_DST_BASE (CYDEV_PERIPH_BASE)
    
    /* DMA Configuration for DMA */
    DMA_Chan = DMA_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE));
    DMA_TD[0] = CyDmaTdAllocate();
    
    CyDmaTdSetConfiguration(DMA_TD[0], NO_SAMPLES, DMA_TD[0], DMA__TD_TERMOUT_EN | TD_INC_SRC_ADR);
    //CyDmaTdSetConfiguration(DMA_TD[0], NO_SAMPLES, DMA_TD[0], TD_INC_SRC_ADR); //hli
    
    CyDmaTdSetAddress(DMA_TD[0], LO16((uint32)Buffer), LO16((uint32)ControlReg_Control_PTR));
    
    CyDmaChSetInitialTd(DMA_Chan, DMA_TD[0]);
    
    //UART_PutHexByte(ControlReg_Read());
    //UART_PutCRLF();
    CyDmaChEnable(DMA_Chan, 1);    /* Enable DMA channel */
    
    return;
}

/* [] END OF FILE */
